<?php
/* Smarty version 3.1.30, created on 2026-04-24 12:54:52
  from "/home/www/_rejestracja/template/partial/Shared/MenuTopTree.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.30',
  'unifunc' => 'content_69eb4bfc1708c9_06841004',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'd425ea4a028909add4945a23b1e2d56df85fe1dc' => 
    array (
      0 => '/home/www/_rejestracja/template/partial/Shared/MenuTopTree.tpl',
      1 => 1490814327,
      2 => 'file',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_69eb4bfc1708c9_06841004 (Smarty_Internal_Template $_smarty_tpl) {
?>
<div class="menu<?php if (!isset($_smarty_tpl->tpl_vars['indexSG']->value)) {?> menuBoxSub<?php }?>" id="menu" style="z-index: 2;">

<ul id="nav">
	<li><a href="<?php echo $_smarty_tpl->tpl_vars['urlMain']->value;?>
" >START</a></li>
                <?php $_smarty_tpl->_assignInScope('countMenuArray', count($_smarty_tpl->tpl_vars['arrayTree']->value));
?> 
								<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['arrayTree']->value, 'item', false, 'key', 'mainMenu', array (
  'last' => true,
  'iteration' => true,
  'total' => true,
));
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['key']->value => $_smarty_tpl->tpl_vars['item']->value) {
$_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['iteration']++;
$_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['last'] = $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['iteration'] == $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['total'];
?>
								<?php $_smarty_tpl->_assignInScope('id', $_smarty_tpl->tpl_vars['item']->value->GetId());
?>
								<?php $_smarty_tpl->_assignInScope('lang', $_smarty_tpl->tpl_vars['item']->value->GetLang());
?>
								<?php $_smarty_tpl->_assignInScope('url', $_smarty_tpl->tpl_vars['item']->value->GetUrlWithType());
?>
								<?php $_smarty_tpl->_assignInScope('urlName', $_smarty_tpl->tpl_vars['item']->value->GetUrl());
?>
								<?php $_smarty_tpl->_assignInScope('name', $_smarty_tpl->tpl_vars['item']->value->GetMenuName());
?>
								<?php $_smarty_tpl->_assignInScope('subname', $_smarty_tpl->tpl_vars['item']->value->GetSubname());
?>
								<?php if (!$_smarty_tpl->tpl_vars['name']->value) {?> <?php $_smarty_tpl->_assignInScope('name', $_smarty_tpl->tpl_vars['item']->value->GetName());
}?>
								<?php if ($_smarty_tpl->tpl_vars['item']->value->GetType() == 1) {?>
									<li <?php if ((isset($_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['last']) ? $_smarty_tpl->tpl_vars['__smarty_foreach_mainMenu']->value['last'] : null)) {?>style="border-right: 0px"<?php }?>><a href="<?php echo $_smarty_tpl->tpl_vars['url']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['name']->value;?>
</a><?php if ($_smarty_tpl->tpl_vars['item']->value->GetHaveChildren()) {?><a class="moreLink" href="#" title="" onclick="showHide('#moreLink_<?php echo $_smarty_tpl->tpl_vars['id']->value;?>
');" >&vee;</a><?php }?>
									<?php if ($_smarty_tpl->tpl_vars['item']->value->GetHaveChildren()) {?>
										<ul id="moreLink_<?php echo $_smarty_tpl->tpl_vars['id']->value;?>
" >
											<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['item']->value->arrayChildren, 'objElementSub', false, 'idElementSub', 'mainSubMenu', array (
));
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['idElementSub']->value => $_smarty_tpl->tpl_vars['objElementSub']->value) {
?>
											<?php $_smarty_tpl->_assignInScope('urlSub', $_smarty_tpl->tpl_vars['objElementSub']->value->GetUrlWithType());
?>
											<?php $_smarty_tpl->_assignInScope('idParentSub', $_smarty_tpl->tpl_vars['objElementSub']->value->GetId());
?>
											<li ><a  href="<?php echo $_smarty_tpl->tpl_vars['urlSub']->value;?>
" ><?php echo $_smarty_tpl->tpl_vars['objElementSub']->value->GetElementName();?>
</a>											</li>
											<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>

										</ul>
									<?php }?>
									
									</li>

                <?php }?>
								<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl);
?>
	
								
</ul>		
					
				<div class="cb"></div>
		</div>				
							
		
	
							 
		
                    <?php }
}
